# SDC.PY
### Official Docs will be in next update

This is an attempt to recreate the module to work with the server-discord.com API

## Installation
--------
```
pip install hmtai
```  
## Example
--------
**Python:**
```py
## SDCPY
import SDCPY

## Get pic from v1 library
print(hmtai.useHM(version="v1", variant="neko"))
## Get pic from v2 library [Some categories has been renamed]
print(hmtai.useHM(version="v2", variant="sfwneko"))
#and etc.
```

## Support
--------
[HMCommunity Discord Server](https://discord.gg/8Cey77R) (If what, mention me on this server (**NickSaltFox#7273**)) || [{~}DiscordSerVe4>](https://discord.com/invite/w9WQgSCxwe)